@@ -4,16 +4,21 @@
 """Lexical analysis of formal languages (i.e. code) using Pygments."""
 
 # :Author: Georg Brandl; Felix Wiemann; Günter Milde
-# :Date: $Date: 2015-04-20 16:05:27 +0200 (Mo, 20 Apr 2015) $
+# :Date: $Date: 2019-08-26 18:46:50 +0200 (Mo, 26. Aug 2019) $
 # :Copyright: This module has been placed in the public domain.
 
 from docutils import ApplicationError
+try:
+    from pkg_resources import DistributionNotFound as ResourceError
+except (ImportError, RuntimeError):
+    class ResourceError(ApplicationError):
+        pass # stub
 try:
     import pygments
     from pygments.lexers import get_lexer_by_name
     from pygments.formatters.html import _get_ttype_class
     with_pygments = True
-except (ImportError, SyntaxError): # pygments 2.0.1 fails with Py 3.1 and 3.2
+except ImportError:
     with_pygments = False
 
 # Filter the following token types from the list of class arguments:
@@ -22,7 +27,7 @@ unstyled_tokens = ['token', # Token (base token type)
                    '']      # short name for Token and Text
 # (Add, e.g., Token.Punctuation with ``unstyled_tokens += 'punctuation'``.)
 
-class LexerError(ApplicationError): 
+class LexerError(ApplicationError):
     pass
 
 class Lexer(object):
@@ -61,21 +66,24 @@ class Lexer(object):
                                     'Pygments package not found.')
         try:
             self.lexer = get_lexer_by_name(self.language)
-        except pygments.util.ClassNotFound:
+        except (pygments.util.ClassNotFound, ResourceError):
             raise LexerError('Cannot analyze code. '
                 'No Pygments lexer found for "%s".' % language)
+        # self.lexer.add_filter('tokenmerge')
+        # Since version 1.2. (released Jan 01, 2010) Pygments has a
+        # TokenMergeFilter. # ``self.merge(tokens)`` in __iter__ could
+        # be replaced by ``self.lexer.add_filter('tokenmerge')`` in __init__.
+        # However, `merge` below also strips a final newline added by pygments.
+        #
+        # self.lexer.add_filter('tokenmerge')
 
-    # Since version 1.2. (released Jan 01, 2010) Pygments has a
-    # TokenMergeFilter. However, this requires Python >= 2.4. When Docutils
-    # requires same minimal version,  ``self.merge(tokens)`` in __iter__ can
-    # be replaced by ``self.lexer.add_filter('tokenmerge')`` in __init__.
     def merge(self, tokens):
         """Merge subsequent tokens of same token-type.
 
            Also strip the final newline (added by pygments).
         """
         tokens = iter(tokens)
-        (lasttype, lastval) = tokens.next()
+        (lasttype, lastval) = next(tokens)
         for ttype, value in tokens:
             if ttype is lasttype:
                 lastval += value
