@@ -1,17 +1,17 @@
 #!/usr/bin/python2
 # -*- coding: utf-8 -*-
 
-# :Id: $Id: latex2mathml.py 7995 2016-12-10 17:50:59Z milde $
+# :Id: $Id: latex2mathml.py 8366 2019-08-27 12:09:19Z milde $
 # :Copyright: © 2010 Günter Milde.
 #             Based on rst2mathml.py from the latex_math sandbox project
 #             © 2005 Jens Jørgen Mortensen
 # :License: Released under the terms of the `2-Clause BSD license`_, in short:
-# 
+#
 #    Copying and distribution of this file, with or without modification,
 #    are permitted in any medium without royalty provided the copyright
 #    notice and this notice are preserved.
 #    This file is offered as-is, without any warranty.
-# 
+#
 # .. _2-Clause BSD license: http://www.spdx.org/licenses/BSD-2-Clause
 
 
@@ -155,7 +155,7 @@ negatables = {'=': u'\u2260',
               r'\equiv': u'\u2262'}
 
 # LaTeX to MathML translation stuff:
-class math:
+class math(object):
     """Base class for MathML elements."""
 
     nchildren = 1000000
@@ -168,7 +168,7 @@ class math:
 
         self.children = []
         if children is not None:
-            if type(children) is list:
+            if isinstance(children, list):
                 for child in children:
                     self.append(child)
             else:
@@ -384,7 +384,6 @@ def parse_latex_math(string, inline=True):
             c2 = string[1]
         else:
             c2 = ''
-##        print n, string, c, c2, node.__class__.__name__
         if c == ' ':
             pass
         elif c == '\\':
@@ -413,7 +412,7 @@ def parse_latex_math(string, inline=True):
                 node = entry
                 skip = 2
             else:
-                raise SyntaxError(ur'Syntax error: "%s%s"' % (c, c2))
+                raise SyntaxError(u'Syntax error: "%s%s"' % (c, c2))
         elif c.isalpha():
             node = node.append(mi(c))
         elif c.isdigit():
@@ -454,7 +453,7 @@ def parse_latex_math(string, inline=True):
             node.close().append(entry)
             node = entry
         else:
-            raise SyntaxError(ur'Illegal character: "%s"' % c)
+            raise SyntaxError(u'Illegal character: "%s"' % c)
         string = string[skip:]
     return tree
 
@@ -475,15 +474,15 @@ def handle_keyword(name, node, string):
         node = entry
     elif name == 'end':
         if not string.startswith('{matrix}'):
-            raise SyntaxError(ur'Expected "\end{matrix}"!')
+            raise SyntaxError(u'Expected "\\end{matrix}"!')
         skip += 8
         node = node.close().close().close()
     elif name in ('text', 'mathrm'):
         if string[0] != '{':
-            raise SyntaxError(ur'Expected "\text{...}"!')
+            raise SyntaxError(u'Expected "\\text{...}"!')
         i = string.find('}')
         if i == -1:
-            raise SyntaxError(ur'Expected "\text{...}"!')
+            raise SyntaxError(u'Expected "\\text{...}"!')
         node = node.append(mtext(string[1:i]))
         skip += i + 1
     elif name == 'sqrt':
@@ -521,7 +520,7 @@ def handle_keyword(name, node, string):
             if string.startswith(operator):
                 break
         else:
-            raise SyntaxError(ur'Expected something to negate: "\not ..."!')
+            raise SyntaxError(u'Expected something to negate: "\\not ..."!')
         node = node.append(mo(negatables[operator]))
         skip += len(operator)
     elif name == 'mathbf':
@@ -530,12 +529,12 @@ def handle_keyword(name, node, string):
         node = style
     elif name == 'mathbb':
         if string[0] != '{' or not string[1].isupper() or string[2] != '}':
-            raise SyntaxError(ur'Expected something like "\mathbb{A}"!')
+            raise SyntaxError(u'Expected something like "\\mathbb{A}"!')
         node = node.append(mi(mathbb[string[1]]))
         skip += 3
     elif name in ('mathscr', 'mathcal'):
         if string[0] != '{' or string[2] != '}':
-            raise SyntaxError(ur'Expected something like "\mathscr{A}"!')
+            raise SyntaxError(u'Expected something like "\\mathscr{A}"!')
         node = node.append(mi(mathscr[string[1]]))
         skip += 3
     elif name == 'colon': # "normal" colon, not binary operator
@@ -560,12 +559,10 @@ def handle_keyword(name, node, string):
     return node, skip
 
 def tex2mathml(tex_math, inline=True):
-    """Return string with MathML code corresponding to `tex_math`. 
-    
+    """Return string with MathML code corresponding to `tex_math`.
+
     `inline`=True is for inline math and `inline`=False for displayed math.
     """
-    
+
     mathml_tree = parse_latex_math(tex_math, inline=inline)
     return ''.join(mathml_tree.xml())
-
-    
